import 'dart:async';
import 'dart:convert';
import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:practica1_flutter/src/http_api/category_api.dart';
import 'package:practica1_flutter/src/models/category_model.dart';

class CategoryController {
  final Connectivity _connectivity = Connectivity();
  final CategoryService _categoryService = CategoryService();

  // Método para obtener las categorías
  Future<Map<String, dynamic>> getCategories() async {
    Map<String, dynamic> mapResp = {
      'ok': false,
      'message': 'No hay categorías',
      'data': null
    };

    ConnectivityResult connectivityResult = await _connectivity.checkConnectivity();
    if (connectivityResult != ConnectivityResult.none) {
      if (connectivityResult == ConnectivityResult.wifi || connectivityResult == ConnectivityResult.mobile) {
        Map<String, dynamic> respGet = await _categoryService.getCategories();
        if (respGet['statusCode'] == 200) {
          try {
            var decodeResp = json.decode(respGet['body']);
            List<CategoryModel> listCategories = CategoryModel.fromJsonArray(decodeResp['data']);
            mapResp['ok'] = true;
            mapResp['message'] = "${listCategories.length} categorías encontradas";
            mapResp['data'] = listCategories;
          } catch (e) {
            mapResp['message'] = "Error en operador $e";
            return mapResp;
          }
        } else {
          mapResp['message'] = "${respGet['body']}";
        }
      }
    }
    return mapResp;
  }

  // Método para agregar una categoría
  Future<Map<String, dynamic>> addCategory(CategoryModel category) async {
    Map<String, dynamic> mapResp = {
      'ok': false,
      'message': 'No se pudo agregar la categoría',
      'data': null
    };

    ConnectivityResult connectivityResult = await _connectivity.checkConnectivity();
    if (connectivityResult != ConnectivityResult.none) {
      if (connectivityResult == ConnectivityResult.wifi || connectivityResult == ConnectivityResult.mobile) {
        Map<String, dynamic> respPost = await _categoryService.addCategory(category);
        if (respPost['statusCode'] == 200) {
          mapResp['ok'] = true;
          mapResp['message'] = "Categoría agregada exitosamente";
          mapResp['data'] = json.decode(respPost['body']);
        } else {
          mapResp['message'] = "${respPost['body']}";
        }
      }
    }
    return mapResp;
  }
}
