import 'dart:async';
import 'dart:convert';
import 'package:http/http.dart' as http;
import 'package:flutter/foundation.dart';
import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:practica1_flutter/environments/api_app.dart';
import 'package:practica1_flutter/src/models/category_model.dart';

class CategoryService {
  // Método para obtener las categorías desde la API
  Future<Map<String, dynamic>> getCategories() async {
    final ConnectivityResult connectivityResult = await (Connectivity().checkConnectivity());

    if (connectivityResult == ConnectivityResult.none) {
      return {"statusCode": 0, "body": "No internet connection"};
    }

    String url = '${apiApp}/categoria?offset=0&max=100';
    if (kDebugMode) {
      print('Url -> $url');
    }
    try {
      final resp = await http.get(Uri.parse(url));
      return {"statusCode": resp.statusCode, "body": resp.body};
    } catch (e) {
      return {"statusCode": 501, "body": '$e'};
    }
  }

  // metodo para agregar una nueva categoría a la API
  Future<Map<String, dynamic>> addCategory(CategoryModel category) async {
    final ConnectivityResult connectivityResult = await (Connectivity().checkConnectivity());

    if (connectivityResult == ConnectivityResult.none) {
      return {"statusCode": 0, "body": "No internet connection"};
    }

    String url = '${apiApp}/categoria';
    if (kDebugMode) {
      print('Url -> $url');
    }

    try {
      final response = await http.post(
        Uri.parse(url),
        headers: {"Content-Type": "application/json"},
        body: json.encode(category.toJson()), // Enviar directamente el JSON del objeto
      );

      return {"statusCode": response.statusCode, "body": response.body};
    } catch (e) {
      return {"statusCode": 501, "body": '$e'};
    }
  }
}
